==> gradle-8.7-rc-1-src.zip: gradle-8.7-rc-1/platforms/software/platform-base/build.gradle.kts <==
plugins {
    id("gradlebuild.distribution.api-java")
}

errorprone {
    disabledChecks.addAll(
        "MixedMutabilityReturnType", // 1 occurrences
        "ModifiedButNotUsed", // 1 occurrences
        "StringCaseLocaleUsage", // 1 occurrences
        "StringSplitter", // 1 occurrences
        "UnusedMethod", // 5 occurrences
    )
}
dependencies {
    implementation(project(":base-services"))
    implementation(project(":logging"))
    implementation(project(":core-api"))
    implementation(project(":files"))
    implementation(project(":model-core"))
    implementation(project(":core"))
    implementation(project(":dependency-management"))
    implementation(project(":workers"))
    implementation(project(":execution"))

    implementation(libs.groovy)
    implementation(libs.guava)
    implementation(libs.commonsLang)
    implementation(libs.inject)

    testImplementation(testFixtures(project(":core")))
    testImplementation(testFixtures(project(":core-api")))
    testImplementation(project(":native"))
    testImplementation(project(":snapshots"))
    testImplementation(project(":process-services"))

    testFixturesApi(project(":core"))
    testFixturesApi(project(":file-collections"))
    testFixturesApi(testFixtures(project(":model-core")))
    testFixturesImplementation(libs.guava)
    testFixturesApi(testFixtures(project(":model-core")))
    testFixturesApi(testFixtures(project(":diagnostics")))

    testRuntimeOnly(project(":distributions-core")) {
        because("RuntimeShadedJarCreatorTest requires a distribution to access the ...-relocated.txt metadata")
    }
    integTestDistributionRuntimeOnly(project(":distributions-core"))
}

packageCycles {
    excludePatterns.add("org/gradle/**")
}

integTest.usesJavadocCodeSnippets = true

description = """Provides general purpose base types and interfaces for modeling projects, and provides runtime and language support."""

==> gradle-8.8-src.zip: gradle-8.8/platforms/software/platform-base/build.gradle.kts <==
plugins {
    id("gradlebuild.distribution.api-java")
}

errorprone {
    disabledChecks.addAll(
        "MixedMutabilityReturnType", // 1 occurrences
        "ModifiedButNotUsed", // 1 occurrences
        "StringCaseLocaleUsage", // 1 occurrences
        "StringSplitter", // 1 occurrences
        "UnusedMethod", // 5 occurrences
    )
}
dependencies {
    api(project(":base-annotations"))
    api(project(":base-services"))
    api(project(":core"))
    api(project(":core-api"))
    api(project(":dependency-management"))
    api(project(":files"))
    api(project(":logging"))
    api(project(":model-core"))

    api(libs.guava)
    api(libs.inject)
    api(libs.jsr305)

    implementation(project(":execution"))

    implementation(libs.commonsLang)

    testImplementation(testFixtures(project(":core")))
    testImplementation(testFixtures(project(":core-api")))
    testImplementation(project(":native"))
    testImplementation(project(":snapshots"))
    testImplementation(project(":process-services"))

    testFixturesApi(project(":file-collections"))
    testFixturesApi(testFixtures(project(":diagnostics")))
    testFixturesApi(testFixtures(project(":model-core")))

    testFixturesImplementation(libs.guava)

    testRuntimeOnly(project(":distributions-core")) {
        because("RuntimeShadedJarCreatorTest requires a distribution to access the ...-relocated.txt metadata")
    }
    integTestDistributionRuntimeOnly(project(":distributions-core"))
}

packageCycles {
    excludePatterns.add("org/gradle/**")
}

integTest.usesJavadocCodeSnippets = true

description = """Provides general purpose base types and interfaces for modeling projects, and provides runtime and language support."""
